@@ -476,6 +476,14 @@ connect_evince_window_finish (LatexilaSynctex *synctex,
 	g_task_propagate_boolean (G_TASK (result), NULL);
 }
 
+static void
+connect_evince_window_simple_cb (GObject      *source_object,
+				 GAsyncResult *result,
+				 gpointer      user_data)
+{
+	connect_evince_window_finish (LATEXILA_SYNCTEX (source_object), result);
+}
+
 /**
  * latexila_synctex_connect_evince_window:
  * @synctex: the #LatexilaSynctex instance.
@@ -491,7 +499,7 @@ latexila_synctex_connect_evince_window (LatexilaSynctex *synctex,
 {
 	connect_evince_window_async (synctex,
 				     pdf_uri,
-				     (GAsyncReadyCallback) connect_evince_window_finish,
+				     connect_evince_window_simple_cb,
 				     NULL);
 }
 
@@ -558,7 +566,7 @@ synctex_file_query_exists_cb (GFile             *synctex_file,
 	if (!synctex_file_exists)
 	{
 		gchar *basename = g_file_get_basename (synctex_file);
-		gchar *message = g_strdup_printf (_ ("The file \"%s\" doesn't exist."), basename);
+		gchar *message = g_strdup_printf (_ ("The file “%s” doesn’t exist."), basename);
 
 		show_warning (message);
 
@@ -592,7 +600,7 @@ pdf_file_query_exists_cb (GFile             *pdf_file,
 
 	if (!pdf_file_exists)
 	{
-		show_warning (_ ("The PDF file doesn't exist."));
+		show_warning (_ ("The PDF file doesn’t exist."));
 		forward_search_data_free (data);
 		return;
 	}
